You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by md...@apache.org on 2011/09/09 13:13:32 UTC

svn commit: r1167095 [2/2] - in /jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit: ./ commons/ commons/cnd/ commons/iterator/ commons/xml/ util/ value/

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/BooleanValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/BooleanValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/BooleanValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/BooleanValue.java Fri Sep  9 11:13:31 2011
@@ -23,8 +23,8 @@ import java.util.Calendar;
 import java.math.BigDecimal;
 
 /**
- * A <code>BooleanValue</code> provides an implementation
- * of the <code>Value</code> interface representing a boolean value.
+ * A {@code BooleanValue} provides an implementation
+ * of the {@code Value} interface representing a boolean value.
  */
 public class BooleanValue extends BaseValue {
 
@@ -33,9 +33,9 @@ public class BooleanValue extends BaseVa
     private final Boolean bool;
 
     /**
-     * Constructs a <code>BooleanValue</code> object representing a boolean.
+     * Constructs a {@code BooleanValue} object representing a boolean.
      *
-     * @param bool the boolean this <code>BooleanValue</code> should represent
+     * @param bool the boolean this {@code BooleanValue} should represent
      */
     public BooleanValue(Boolean bool) {
         super(TYPE);
@@ -43,9 +43,9 @@ public class BooleanValue extends BaseVa
     }
 
     /**
-     * Constructs a <code>BooleanValue</code> object representing a boolean.
+     * Constructs a {@code BooleanValue} object representing a boolean.
      *
-     * @param bool the boolean this <code>BooleanValue</code> should represent
+     * @param bool the boolean this {@code BooleanValue} should represent
      */
     public BooleanValue(boolean bool) {
         super(TYPE);
@@ -53,11 +53,11 @@ public class BooleanValue extends BaseVa
     }
 
     /**
-     * Returns a new <code>BooleanValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code BooleanValue} initialized to the value
+     * represented by the specified {@code String}.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>BooleanValue</code> representing the
+     * @return a newly constructed {@code BooleanValue} representing the
      *         the specified value.
      */
     public static BooleanValue valueOf(String s) {
@@ -67,13 +67,13 @@ public class BooleanValue extends BaseVa
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>BooleanValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code BooleanValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -102,9 +102,7 @@ public class BooleanValue extends BaseVa
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (bool != null) {
             return bool.toString();
@@ -114,30 +112,15 @@ public class BooleanValue extends BaseVa
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         if (bool != null) {
             return bool;
         } else {
@@ -145,21 +128,11 @@ public class BooleanValue extends BaseVa
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DecimalValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DecimalValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DecimalValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DecimalValue.java Fri Sep  9 11:13:31 2011
@@ -24,8 +24,8 @@ import java.util.Date;
 import java.math.BigDecimal;
 
 /**
- * A <code>DecimalValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>DECIMAL</code> value.
+ * A {@code DecimalValue} provides an implementation
+ * of the {@code Value} interface representing a {@code DECIMAL} value.
  */
 public class DecimalValue extends BaseValue {
 
@@ -34,9 +34,9 @@ public class DecimalValue extends BaseVa
     private final BigDecimal number;
 
     /**
-     * Constructs a <code>DecimalValue</code> object representing a decimal.
+     * Constructs a {@code DecimalValue} object representing a decimal.
      *
-     * @param number the decimal this <code>DecimalValue</code> should represent
+     * @param number the decimal this {@code DecimalValue} should represent
      */
     public DecimalValue(BigDecimal number) {
         super(TYPE);
@@ -44,14 +44,14 @@ public class DecimalValue extends BaseVa
     }
 
     /**
-     * Returns a new <code>DecimalValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code DecimalValue} initialized to the value
+     * represented by the specified {@code String}.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>DecimalValue</code> representing the
+     * @return a newly constructed {@code DecimalValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> does not
-     *                                        contain a parsable <code>decimal</code>.
+     * @throws javax.jcr.ValueFormatException If the {@code String} does not
+     *                                        contain a parseable {@code decimal}.
      */
     public static DecimalValue valueOf(String s) throws ValueFormatException {
         try {
@@ -64,13 +64,13 @@ public class DecimalValue extends BaseVa
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>DecimalValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code DecimalValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -99,9 +99,7 @@ public class DecimalValue extends BaseVa
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (number != null) {
             return number.toString();
@@ -111,12 +109,8 @@ public class DecimalValue extends BaseVa
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         if (number != null) {
             // loosing timezone information...
             Calendar cal = Calendar.getInstance();
@@ -127,12 +121,7 @@ public class DecimalValue extends BaseVa
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         if (number != null) {
             return number.longValue();
         } else {
@@ -140,21 +129,11 @@ public class DecimalValue extends BaseVa
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         if (number != null) {
             return number.doubleValue();
         } else {
@@ -162,16 +141,11 @@ public class DecimalValue extends BaseVa
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         if (number != null) {
             return number;
         } else {
             throw new ValueFormatException("empty value");
         }
     }
-}
\ No newline at end of file
+}

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DoubleValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DoubleValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DoubleValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/DoubleValue.java Fri Sep  9 11:13:31 2011
@@ -24,8 +24,8 @@ import java.util.Date;
 import java.math.BigDecimal;
 
 /**
- * A <code>DoubleValue</code> provides an implementation
- * of the <code>Value</code> interface representing a double value.
+ * A {@code DoubleValue} provides an implementation
+ * of the {@code Value} interface representing a double value.
  */
 public class DoubleValue extends BaseValue {
 
@@ -34,9 +34,9 @@ public class DoubleValue extends BaseVal
     private final Double dblNumber;
 
     /**
-     * Constructs a <code>DoubleValue</code> object representing a double.
+     * Constructs a {@code DoubleValue} object representing a double.
      *
-     * @param dblNumber the double this <code>DoubleValue</code> should represent
+     * @param dblNumber the double this {@code DoubleValue} should represent
      */
     public DoubleValue(Double dblNumber) {
         super(TYPE);
@@ -44,24 +44,24 @@ public class DoubleValue extends BaseVal
     }
 
     /**
-     * Constructs a <code>DoubleValue</code> object representing a double.
+     * Constructs a {@code DoubleValue} object representing a double.
      *
-     * @param dbl the double this <code>DoubleValue</code> should represent
+     * @param dbl the double this {@code DoubleValue} should represent
      */
     public DoubleValue(double dbl) {
         super(TYPE);
-        this.dblNumber = dbl;
+        dblNumber = dbl;
     }
 
     /**
-     * Returns a new <code>DoubleValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code DoubleValue} initialized to the value
+     * represented by the specified {@code String}.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>DoubleValue</code> representing the
+     * @return a newly constructed {@code DoubleValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> does not
-     *                                        contain a parsable <code>double</code>.
+     * @throws javax.jcr.ValueFormatException If the {@code String} does not
+     *                                        contain a parseable {@code double}.
      */
     public static DoubleValue valueOf(String s) throws ValueFormatException {
         try {
@@ -74,13 +74,13 @@ public class DoubleValue extends BaseVal
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>DoubleValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code DoubleValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -109,9 +109,7 @@ public class DoubleValue extends BaseVal
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (dblNumber != null) {
             return dblNumber.toString();
@@ -121,12 +119,7 @@ public class DoubleValue extends BaseVal
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         if (dblNumber != null) {
             // loosing timezone information...
             Calendar cal = Calendar.getInstance();
@@ -137,12 +130,7 @@ public class DoubleValue extends BaseVal
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         if (dblNumber != null) {
             return dblNumber.longValue();
         } else {
@@ -150,21 +138,11 @@ public class DoubleValue extends BaseVal
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         if (dblNumber != null) {
             return dblNumber;
         } else {
@@ -172,12 +150,7 @@ public class DoubleValue extends BaseVal
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         if (dblNumber != null) {
             return new BigDecimal(dblNumber);
         } else {

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/LongValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/LongValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/LongValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/LongValue.java Fri Sep  9 11:13:31 2011
@@ -24,8 +24,8 @@ import java.util.Date;
 import java.math.BigDecimal;
 
 /**
- * A <code>LongValue</code> provides an implementation
- * of the <code>Value</code> interface representing a long value.
+ * A {@code LongValue} provides an implementation
+ * of the {@code Value} interface representing a long value.
  */
 public class LongValue extends BaseValue {
 
@@ -34,9 +34,9 @@ public class LongValue extends BaseValue
     private final Long lNumber;
 
     /**
-     * Constructs a <code>LongValue</code> object representing a long.
+     * Constructs a {@code LongValue} object representing a long.
      *
-     * @param lNumber the long this <code>LongValue</code> should represent
+     * @param lNumber the long this {@code LongValue} should represent
      */
     public LongValue(Long lNumber) {
         super(TYPE);
@@ -44,24 +44,24 @@ public class LongValue extends BaseValue
     }
 
     /**
-     * Constructs a <code>LongValue</code> object representing a long.
+     * Constructs a {@code LongValue} object representing a long.
      *
-     * @param l the long this <code>LongValue</code> should represent
+     * @param l the long this {@code LongValue} should represent
      */
     public LongValue(long l) {
         super(TYPE);
-        this.lNumber = l;
+        lNumber = l;
     }
 
     /**
-     * Returns a new <code>LongValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code LongValue} initialized to the value
+     * represented by the specified {@code String}.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>LongValue</code> representing the
+     * @return a newly constructed {@code LongValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> does not
-     *                                        contain a parsable <code>long</code>.
+     * @throws javax.jcr.ValueFormatException If the {@code String} does not
+     *                                        contain a parseable {@code long}.
      */
     public static LongValue valueOf(String s) throws ValueFormatException {
         try {
@@ -74,13 +74,13 @@ public class LongValue extends BaseValue
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>LongValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code LongValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -109,9 +109,7 @@ public class LongValue extends BaseValue
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (lNumber != null) {
             return lNumber.toString();
@@ -121,12 +119,7 @@ public class LongValue extends BaseValue
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         if (lNumber != null) {
             // loosing timezone information...
             Calendar cal = Calendar.getInstance();
@@ -137,12 +130,7 @@ public class LongValue extends BaseValue
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         if (lNumber != null) {
             return lNumber;
         } else {
@@ -150,21 +138,11 @@ public class LongValue extends BaseValue
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         if (lNumber != null) {
             return lNumber.doubleValue();
         } else {
@@ -172,12 +150,7 @@ public class LongValue extends BaseValue
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         if (lNumber != null) {
             return new BigDecimal(lNumber);
         } else {

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/NameValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/NameValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/NameValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/NameValue.java Fri Sep  9 11:13:31 2011
@@ -23,8 +23,8 @@ import java.util.Calendar;
 import java.math.BigDecimal;
 
 /**
- * A <code>NameValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>NAME</code> value
+ * A {@code NameValue} provides an implementation
+ * of the {@code Value} interface representing a {@code NAME} value
  * (a string that is namespace-qualified).
  */
 public class NameValue extends BaseValue {
@@ -34,15 +34,15 @@ public class NameValue extends BaseValue
     private final String name;
 
     /**
-     * Returns a new <code>NameValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code NameValue} initialized to the value
+     * represented by the specified {@code String}.
      * <p/>
-     * The specified <code>String</code> must be a valid JCR name.
+     * The specified {@code String} must be a valid JCR name.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>NameValue</code> representing the
+     * @return a newly constructed {@code NameValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> is not a valid
+     * @throws javax.jcr.ValueFormatException If the {@code String} is not a valid
      *                              name.
      */
     public static NameValue valueOf(String s) throws ValueFormatException {
@@ -55,10 +55,10 @@ public class NameValue extends BaseValue
 
 
     /**
-     * Protected constructor creating a <code>NameValue</code> object
+     * Protected constructor creating a {@code NameValue} object
      * without validating the name.
      *
-     * @param name the name this <code>NameValue</code> should represent
+     * @param name the name this {@code NameValue} should represent
      * @see #valueOf
      */
     protected NameValue(String name) {
@@ -69,13 +69,13 @@ public class NameValue extends BaseValue
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>NameValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code NameValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -104,9 +104,7 @@ public class NameValue extends BaseValue
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (name != null) {
             return name;
@@ -116,48 +114,24 @@ public class NameValue extends BaseValue
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/PathValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/PathValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/PathValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/PathValue.java Fri Sep  9 11:13:31 2011
@@ -23,8 +23,8 @@ import java.util.Calendar;
 import java.math.BigDecimal;
 
 /**
- * A <code>PathValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>PATH</code> value
+ * A {@code PathValue} provides an implementation
+ * of the {@code Value} interface representing a {@code PATH} value
  * (an absolute or relative workspace path).
  */
 public class PathValue extends BaseValue {
@@ -34,16 +34,16 @@ public class PathValue extends BaseValue
     private final String path;
 
     /**
-     * Returns a new <code>PathValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code PathValue} initialized to the value
+     * represented by the specified {@code String}.
      * <p/>
-     * The specified <code>String</code> must be a valid absolute or relative
+     * The specified {@code String} must be a valid absolute or relative
      * path.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>PathValue</code> representing the
+     * @return a newly constructed {@code PathValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> is not a valid
+     * @throws javax.jcr.ValueFormatException If the {@code String} is not a valid
      *                              absolute or relative path.
      */
     public static PathValue valueOf(String s) throws ValueFormatException {
@@ -55,10 +55,10 @@ public class PathValue extends BaseValue
     }
 
     /**
-     * Protected constructor creating a <code>PathValue</code> object
+     * Protected constructor creating a {@code PathValue} object
      * without validating the path.
      *
-     * @param path the path this <code>PathValue</code> should represent
+     * @param path the path this {@code PathValue} should represent
      * @see #valueOf
      */
     protected PathValue(String path) {
@@ -69,13 +69,13 @@ public class PathValue extends BaseValue
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>PathValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code PathValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -104,9 +104,7 @@ public class PathValue extends BaseValue
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (path != null) {
             return path;
@@ -116,48 +114,23 @@ public class PathValue extends BaseValue
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/ReferenceValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/ReferenceValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/StringValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/StringValue.java Fri Sep  9 11:13:31 2011
@@ -20,8 +20,8 @@ import javax.jcr.PropertyType;
 import javax.jcr.ValueFormatException;
 
 /**
- * A <code>StringValue</code> provides an implementation
- * of the <code>Value</code> interface representing a string value.
+ * A {@code StringValue} provides an implementation
+ * of the {@code Value} interface representing a string value.
  */
 public class StringValue extends BaseValue {
 
@@ -30,9 +30,9 @@ public class StringValue extends BaseVal
     private final String text;
 
     /**
-     * Constructs a <code>StringValue</code> object representing a string.
+     * Constructs a {@code StringValue} object representing a string.
      *
-     * @param text the string this <code>StringValue</code> should represent
+     * @param text the string this {@code StringValue} should represent
      */
     public StringValue(String text) {
         super(TYPE);
@@ -42,13 +42,13 @@ public class StringValue extends BaseVal
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>StringValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code StringValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -77,9 +77,7 @@ public class StringValue extends BaseVal
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (text != null) {
             return text;

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/URIValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/URIValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/URIValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/URIValue.java Fri Sep  9 11:13:31 2011
@@ -25,8 +25,8 @@ import java.net.URISyntaxException;
 import java.math.BigDecimal;
 
 /**
- * A <code>URIValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>URI</code> value
+ * A {@code URIValue} provides an implementation
+ * of the {@code Value} interface representing a {@code URI} value
  * (an absolute or relative workspace path).
  */
 public class URIValue extends BaseValue {
@@ -36,15 +36,15 @@ public class URIValue extends BaseValue 
     private final URI uri;
 
     /**
-     * Returns a new <code>URIValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code URIValue} initialized to the value
+     * represented by the specified {@code String}.
      * <p/>
-     * The specified <code>String</code> must be a valid URI.
+     * The specified {@code String} must be a valid URI.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>URIValue</code> representing the
+     * @return a newly constructed {@code URIValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> is not a valid URI.
+     * @throws javax.jcr.ValueFormatException If the {@code String} is not a valid URI.
      */
     public static URIValue valueOf(String s) throws ValueFormatException {
         if (s != null) {
@@ -59,10 +59,10 @@ public class URIValue extends BaseValue 
     }
 
     /**
-     * Returns a new <code>URIValue</code> initialized to the value of the
+     * Returns a new {@code URIValue} initialized to the value of the
      * specified URI.
      *
-     * @param uri the path this <code>URIValue</code> should represent
+     * @param uri the path this {@code URIValue} should represent
      * @see #valueOf
      */
     public URIValue(URI uri) {
@@ -73,13 +73,13 @@ public class URIValue extends BaseValue 
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>URIValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code URIValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -108,9 +108,7 @@ public class URIValue extends BaseValue 
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (uri != null) {
             return uri.toString();
@@ -120,48 +118,24 @@ public class URIValue extends BaseValue 
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }
\ No newline at end of file

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/WeakReferenceValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/WeakReferenceValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/ReferenceValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/ReferenceValue.java Fri Sep  9 11:13:31 2011
@@ -26,8 +26,8 @@ import java.util.UUID;
 import java.math.BigDecimal;
 
 /**
- * A <code>ReferenceValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>REFERENCE</code> value
+ * A {@code ReferenceValue} provides an implementation
+ * of the {@code Value} interface representing a {@code REFERENCE} value
  * (a UUID of an existing node).
  */
 public class ReferenceValue extends BaseValue {
@@ -37,33 +37,33 @@ public class ReferenceValue extends Base
     private final String uuid;
 
     /**
-     * Constructs a <code>ReferenceValue</code> object representing the UUID of
+     * Constructs a {@code ReferenceValue} object representing the UUID of
      * an existing node.
      *
      * @param target the node to be referenced
      * @throws IllegalArgumentException If <code>target</code> is nonreferenceable.
      * @throws javax.jcr.RepositoryException      If another error occurs.
      */
     public ReferenceValue(Node target) throws RepositoryException {
         super(TYPE);
         try {
-            this.uuid = target.getUUID();
+            uuid = target.getUUID();
         } catch (UnsupportedRepositoryOperationException ure) {
-            throw new IllegalArgumentException("target is nonreferenceable.");
+            throw new IllegalArgumentException("target is not referenceable.");
         }
     }
 
     /**
-     * Returns a new <code>ReferenceValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code ReferenceValue} initialized to the value
+     * represented by the specified {@code String}.
      * <p/>
-     * The specified <code>String</code> must denote the UUID of an existing
+     * The specified {@code String} must denote the UUID of an existing
      * node.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>ReferenceValue</code> representing the
+     * @return a newly constructed {@code ReferenceValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> is not a valid
+     * @throws javax.jcr.ValueFormatException If the {@code String} is not a valid
      *                              not a valid UUID format.
      */
     public static ReferenceValue valueOf(String s) throws ValueFormatException {
@@ -80,7 +80,7 @@ public class ReferenceValue extends Base
     }
 
     /**
-     * Protected constructor creating a <code>ReferenceValue</code> object
+     * Protected constructor creating a {@code ReferenceValue} object
      * without validating the UUID format.
      *
      * @param uuid the UUID of the node to be referenced
@@ -94,13 +94,13 @@ public class ReferenceValue extends Base
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>ReferenceValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code ReferenceValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -129,9 +129,7 @@ public class ReferenceValue extends Base
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (uuid != null) {
             return uuid;
@@ -141,48 +139,24 @@ public class ReferenceValue extends Base
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }
@@ -37,33 +37,33 @@ public class ReferenceValue extends Base
      *
      * @param target the node to be referenced
-     * @throws IllegalArgumentException If <code>target</code> is nonreferenceable.
+     * @throws IllegalArgumentException If {@code target} is not referenceable.
      * @throws javax.jcr.RepositoryException      If another error occurs.
      */

Modified: jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/StringValue.java
URL: http://svn.apache.org/viewvc/jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/StringValue.java?rev=1167095&r1=1167094&r2=1167095&view=diff
==============================================================================
--- jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/WeakReferenceValue.java (original)
+++ jackrabbit/sandbox/jackrabbit-mk/jackrabbit-jcr-commons/src/main/java/org/apache/jackrabbit/value/WeakReferenceValue.java Fri Sep  9 11:13:31 2011
@@ -26,8 +26,8 @@ import java.util.UUID;
 import java.math.BigDecimal;
 
 /**
- * A <code>WeakReferenceValue</code> provides an implementation
- * of the <code>Value</code> interface representing a <code>WEAKREFERENCE</code> value
+ * A {@code WeakReferenceValue} provides an implementation
+ * of the {@code Value} interface representing a {@code WEAKREFERENCE} value
  * (a UUID of an existing node).
  */
 public class WeakReferenceValue extends BaseValue {
@@ -37,33 +37,33 @@ public class WeakReferenceValue extends 
     private final String uuid;
 
     /**
-     * Constructs a <code>ReferenceValue</code> object representing the UUID of
+     * Constructs a {@code ReferenceValue} object representing the UUID of
      * an existing node.
      *
      * @param target the node to be referenced
      * @throws IllegalArgumentException If <code>target</code> is nonreferenceable.
      * @throws javax.jcr.RepositoryException      If another error occurs.
      */
     public WeakReferenceValue(Node target) throws RepositoryException {
         super(TYPE);
         try {
-            this.uuid = target.getUUID();
+            uuid = target.getUUID();
         } catch (UnsupportedRepositoryOperationException ure) {
-            throw new IllegalArgumentException("target is nonreferenceable.");
+            throw new IllegalArgumentException("target is not referenceable.");
         }
     }
 
     /**
-     * Returns a new <code>ReferenceValue</code> initialized to the value
-     * represented by the specified <code>String</code>.
+     * Returns a new {@code ReferenceValue} initialized to the value
+     * represented by the specified {@code String}.
      * <p/>
-     * The specified <code>String</code> must denote the UUID of an existing
+     * The specified {@code String} must denote the UUID of an existing
      * node.
      *
      * @param s the string to be parsed.
-     * @return a newly constructed <code>ReferenceValue</code> representing the
+     * @return a newly constructed {@code ReferenceValue} representing the
      *         the specified value.
-     * @throws javax.jcr.ValueFormatException If the <code>String</code> is not a valid
+     * @throws javax.jcr.ValueFormatException If the {@code String} is not a valid
      *                              not a valid UUID format.
      */
     public static WeakReferenceValue valueOf(String s) throws ValueFormatException {
@@ -80,7 +80,7 @@ public class WeakReferenceValue extends 
     }
 
     /**
-     * Protected constructor creating a <code>ReferenceValue</code> object
+     * Protected constructor creating a {@code ReferenceValue} object
      * without validating the UUID format.
      *
      * @param uuid the UUID of the node to be referenced
@@ -94,13 +94,13 @@ public class WeakReferenceValue extends 
     /**
      * Indicates whether some other object is "equal to" this one.
      * <p/>
-     * The result is <code>true</code> if and only if the argument is not
-     * <code>null</code> and is a <code>ReferenceValue</code> object that
+     * The result is {@code true} if and only if the argument is not
+     * {@code null} and is a {@code ReferenceValue} object that
      * represents the same value as this object.
      *
      * @param obj the reference object with which to compare.
-     * @return <code>true</code> if this object is the same as the obj
-     *         argument; <code>false</code> otherwise.
+     * @return {@code true} if this object is the same as the obj
+     *         argument; {@code false} otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -129,9 +129,7 @@ public class WeakReferenceValue extends 
     }
 
     //------------------------------------------------------------< BaseValue >
-    /**
-     * {@inheritDoc}
-     */
+
     protected String getInternalString() throws ValueFormatException {
         if (uuid != null) {
             return uuid;
@@ -141,48 +139,24 @@ public class WeakReferenceValue extends 
     }
 
     //----------------------------------------------------------------< Value >
-    /**
-     * {@inheritDoc}
-     */
-    public Calendar getDate()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+
+    public Calendar getDate() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to date failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public long getLong()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public long getLong() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to long failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public boolean getBoolean()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public boolean getBoolean() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to boolean failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public double getDouble()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public double getDouble() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to double failed: inconvertible types");
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public BigDecimal getDecimal()
-            throws ValueFormatException, IllegalStateException,
-            RepositoryException {
+    public BigDecimal getDecimal() throws IllegalStateException, RepositoryException {
         throw new ValueFormatException("conversion to Decimal failed: inconvertible types");
     }
 }
@@ -37,33 +37,33 @@ public class WeakReferenceValue extends 
      *
      * @param target the node to be referenced
-     * @throws IllegalArgumentException If <code>target</code> is nonreferenceable.
+     * @throws IllegalArgumentException If {@code target} is not referenceable.
      * @throws javax.jcr.RepositoryException      If another error occurs.
      */
\ No newline at end of file